import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This application demonstrates how to adjust the start and end gaps 
 * of all series displayed in a chart.
 * The  starting gap is the distance from the vertical axis to the first
 * label coordinate, in vertical charts, or the distance from the top of
 * the vertical axis to the first label coordinate, in horizontal charts.
 *
 * The end gap is the distance from the last label coordinate to the end
 * of the horizontal axis, in vertical charts, or the distance from the
 * last label coordinate to the end of the vertical axis, in horizontal
 * charts.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements AdjustmentListener,ItemListener {

    Graph graph;

    LineSerie ls;
    AreaSerie as;

    JScrollBar sb1,sb2;
    JCheckBox cb;

    public Main() {
	
	// Sets the frame title.
	setTitle("The JetChart Library - Adjusting the start and end series gaps");
	
	
	sb1=new JScrollBar(JScrollBar.HORIZONTAL,10,20,0,100);
        sb1.setPreferredSize(new Dimension(100,sb1.getPreferredSize().height));

	sb2=new JScrollBar(JScrollBar.HORIZONTAL,10,20,0,100);
        sb2.setPreferredSize(new Dimension(100,sb2.getPreferredSize().height));

	sb1.addAdjustmentListener(this);
	sb2.addAdjustmentListener(this);

	cb=new JCheckBox("Horizontal");
	cb.addItemListener(this);

	JPanel p=new JPanel(new FlowLayout(FlowLayout.LEFT));
	p.add(cb);
	p.add(new JLabel("Start gap:"));
	p.add(sb1);
	p.add(new JLabel("End gap:"));
	p.add(sb2);

        Container ct=getContentPane();

	ct.add("North",p);

	// Series values.
	double[] values1={1117,1122,1110,1300,1400,1108,1100,2100,3100,1800};
	double[] values2={3543,2243,1890,2991,3654,2500,1600,1900,2200,3000};

	// Creates a line series.
	ls=new LineSerie(values1,"Line Series");
	ls.setColor(Color.magenta);
	ls.setThickness(2);

	// Creates an area series.
	as=new AreaSerie(values2,"Area Series");
	as.setColor(Color.red);

	graph=new Graph(new String[]{"l1","l2","l3","l4","l5","l6","l7","l8","l9","l10"});

	graph.setTitle(new String[]{"The JetChart Library","Adjusting the start and end series gaps"});
	graph.set3DEnabled(true);

	graph.addSerie(as);
	graph.addSerie(ls);

	ct.add("Center",graph);

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(500,450);

	setVisible(true);

    }

    public void itemStateChanged(ItemEvent evt) {
	graph.setHorizontalGraphEnabled(cb.isSelected());
	graph.refresh();
    }

    public void adjustmentValueChanged(AdjustmentEvent evt) {

	// Sets the labels axis starting gap
	if (evt.getSource()==sb1) {
	    int value=sb1.getValue();
	    graph.setLabelsAxisStartGap(value);
	}
	
	// Sets the labels axis end gap
	if (evt.getSource()==sb2) {
	    int value=sb2.getValue();
	    graph.setLabelsAxisEndGap(value);
	}
	graph.refresh();
    }
    

    public static void main(String[] args) {
	new Main();
    }
}
