import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import java.util.Locale;

/**
 * This  application  demonstrates  how  to  get labels and series values from an XML source.
 * The GenericGraph  class  implements  the  method  GenericGraph.readXMLData(Reader reader),
 * which  can  be  invoked  from  subclasses  to  populate   chart labels  and series values. 
 * In  this  demo,  the  Graph class  is  instantiated  and  used to display two OHLC series. 
 * Labels and values are read from the ohlc.xml text file. Open  this  file to get additional
 * information concerning the XML elements used to retrieve labels and values. 
 *
 * @author - Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame {

    OHLCBarSerie bs;
    OHLCLineSerie ls;
    
    Graph graph;

    public Main() {

	setTitle("The JetChart Library - reading data from an XML file");
	setSize(650,400);

	// Creates an anonymous class to close application.
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	// Creates the chart context.
	createChartContext();
	
	// Creates an OHLC bar series.
	createOHLCBarSerie();
	
	// Creates an OHLC line series.
	createOHLCLineSerie();
	
	// Adds series to the chart context.
	graph.addSerie(bs);
	graph.addSerie(ls);

	// Reads the ohlc.xml file.
	readXMLData(graph);

        Container ct=getContentPane();

	ct.add("Center",graph);

	setVisible(true);

    }

    private void createChartContext() {

	// Creates the chart context.
	graph=new Graph();

	graph.setTitle(new String[]{"The JetChart Library","Reading data from an XML file"});
	
	// Sets the labels font.
	graph.setLabelsFont(new Font("SansSerif",Font.PLAIN,10));

	// Enables grid and colored bands.
	Grid grid=graph.getGraphSet(0).getGrid();
	grid.setEnabled(true);
	grid.setColoredBandsEnabled(true);

	// Sets scale value format.
	Scale scale=graph.getGraphSet(0).getScale();
	scale.setValueFormat("###,##0.00");

    }

    private void createOHLCBarSerie() {

	// Creates an OHLC bar series.
	bs=new OHLCBarSerie();
	
	// The series id is set to 0. This value must match the 'id' attribute value 
	// found in the ohlc.xml file, added to the <series> xml element.
	bs.setId(0);
	
	// Sets the dash size and bar width.
	bs.setDashSize(3);
	bs.setWidth(1);
	
	// Sets the OHLC bar series color to blue.
	bs.setColor(Color.blue);
	
	// Sets the OHLC bar series title.
	bs.setTitle("OHLC bar series");

    }

    private void createOHLCLineSerie() {
	
	// Creates an OHLC line series.
	ls=new OHLCLineSerie();
	
	// The series id is set to 1. This value must match the 'id' attribute value 
	// found in the ohlc.xml file, added to the <series> xml element.
	ls.setId(1);

	// Sets ohlc line series title.
	ls.setTitle("OHLC line series");
	// Disables data points marks.
	ls.setMarksEnabled(false);
	// Sets line series color to red.
	ls.setColor(Color.red);
	// Sets line thickness to two pixels.
	ls.setThickness(2);

    }
	
    private void readXMLData(Graph graph) {
	
	FileReader fr=null;

	// The readXMLData method below throws an IOException, so we must enclose it
	// within a try-catch block.
	try {

	    // Opens a character stream to read the ohlc.xml file.
	    fr=new FileReader("ohlc.xml");

	    // Parses the xml file. While parsing, labels and values are assigned to 
	    // the chart context and respective series.
	    graph.readXMLData(fr);

	    fr.close();

	}
	catch (Exception e) {
	    e.printStackTrace();
	}
	finally {
	    try {
		if (fr!=null)
		    fr.close();
	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}

    }

	    

    public static void main(String[] args) {
	new Main();
    }

}
